import { defineComponent, ref, createElementBlock, openBlock, createElementVNode, withDirectives, Fragment, renderList, unref, createBlock, createCommentVNode, toDisplayString, normalizeClass, createVNode, vShow } from "vue";
import { storeToRefs } from "pinia";
import { useRoomStore } from "../../stores/room.mjs";
import Avatar from "../common/Avatar.vue2.mjs";
import AudienceLevel from "../common/AudienceLevel.vue.mjs";
import SvgIcon from "../common/base/SvgIcon.vue.mjs";
import ArrowStrokeBackIcon from "../common/icons/ArrowStrokeBackIcon.vue.mjs";
import { useI18n } from "../../locales/index.mjs";
import defaultAvatarImage from "../../assets/imgs/avatar.png.mjs";
import { MAX_RENDER_AUDIENCE_COUNT } from "../../constants/render.mjs";
const _hoisted_1 = { class: "tui-audience-list-h5" };
const _hoisted_2 = { class: "audience-list" };
const _hoisted_3 = { class: "audience-count" };
const _hoisted_4 = { class: "audience-popup-header" };
const _hoisted_5 = { class: "audience-popup-title" };
const _hoisted_6 = { class: "audience-popup-list" };
const _hoisted_7 = {
  key: 1,
  class: "audience-popup-info"
};
const _hoisted_8 = { class: "audience-popup-name" };
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "AudienceListH5",
  setup(__props) {
    const { t } = useI18n();
    const isDisplayPopup = ref(false);
    const roomStore = useRoomStore();
    const { audienceList } = storeToRefs(roomStore);
    const audiencePopupElement = ref();
    const handleDisplayPopup = () => {
      isDisplayPopup.value = true;
      if (!audiencePopupElement.value) return;
      audiencePopupElement.value.style.transition = "transform 0.4s";
    };
    const handleCollapsePopup = () => {
      isDisplayPopup.value = false;
    };
    const handleTransitionEnd = (event) => {
      if (event.propertyName === "transform") {
        if (!isDisplayPopup.value) {
          if (!audiencePopupElement.value) return;
          audiencePopupElement.value.style.transition = "none";
        }
      }
    };
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1, [
        createElementVNode("div", {
          class: "audience-list-button",
          onClick: handleDisplayPopup
        }, [
          createElementVNode("div", _hoisted_2, [
            (openBlock(true), createElementBlock(Fragment, null, renderList(unref(audienceList), (audience, index) => {
              return openBlock(), createElementBlock("div", null, [
                index < 2 ? (openBlock(), createBlock(Avatar, {
                  key: 0,
                  class: "audience-item",
                  "img-src": audience.avatarUrl ? audience.avatarUrl : unref(defaultAvatarImage)
                }, null, 8, ["img-src"])) : createCommentVNode("", true)
              ]);
            }), 256))
          ]),
          createElementVNode("div", _hoisted_3, toDisplayString(unref(audienceList).length), 1)
        ]),
        createElementVNode("div", {
          ref_key: "audiencePopupElement",
          ref: audiencePopupElement,
          onTransitionend: handleTransitionEnd,
          class: normalizeClass(["audience-popup", { "display-popup": isDisplayPopup.value }])
        }, [
          createElementVNode("div", _hoisted_4, [
            createVNode(SvgIcon, {
              class: "svg-icon",
              size: "12",
              icon: ArrowStrokeBackIcon,
              onClick: handleCollapsePopup
            }),
            createElementVNode("div", _hoisted_5, toDisplayString(unref(t)("Online audience")) + " (" + toDisplayString(unref(audienceList).length) + ")", 1)
          ]),
          createElementVNode("div", _hoisted_6, [
            (openBlock(true), createElementBlock(Fragment, null, renderList(unref(audienceList), (audience, index) => {
              return openBlock(), createElementBlock("div", {
                class: "audience-popup-item",
                key: audience == null ? void 0 : audience.userId
              }, [
                index < unref(MAX_RENDER_AUDIENCE_COUNT) ? (openBlock(), createBlock(Avatar, {
                  key: 0,
                  class: "audience-popup-avatar",
                  "img-src": audience == null ? void 0 : audience.avatarUrl
                }, null, 8, ["img-src"])) : createCommentVNode("", true),
                index < unref(MAX_RENDER_AUDIENCE_COUNT) ? (openBlock(), createElementBlock("div", _hoisted_7, [
                  createElementVNode("span", _hoisted_8, toDisplayString((audience == null ? void 0 : audience.userName) || (audience == null ? void 0 : audience.userId)), 1),
                  createVNode(AudienceLevel, { level: 0 })
                ])) : createCommentVNode("", true)
              ]);
            }), 128))
          ])
        ], 34),
        withDirectives(createElementVNode("div", {
          class: "audience-popup-mask",
          onClick: handleCollapsePopup
        }, null, 512), [
          [vShow, isDisplayPopup.value]
        ])
      ]);
    };
  }
});
export {
  _sfc_main as default
};
