import { ref, watch } from "vue";
import { storeToRefs } from "pinia";
import { TencentCloudChat } from "@tencentcloud/tuiroom-engine-js";
import renderMsg from "../../common/base/Message/Message.mjs";
import useGetRoomEngine from "../../../hooks/useRoomEngine.mjs";
import { useChatStore } from "../../../stores/chat.mjs";
import { useRoomStore } from "../../../stores/room.mjs";
import { useI18n } from "../../../locales/index.mjs";
import { useBasicStore } from "../../../stores/basic.mjs";
import { decodeSendTextMsg } from "../util.mjs";
function useChatEditor() {
  const roomEngine = useGetRoomEngine();
  const basicStore = useBasicStore();
  const chatStore = useChatStore();
  const roomStore = useRoomStore();
  const { t } = useI18n();
  const { roomId } = storeToRefs(basicStore);
  const { isMessageDisabled } = storeToRefs(chatStore);
  const editorInputEle = ref();
  const sendMsg = ref("");
  const isEmojiToolbarVisible = ref(false);
  watch(isMessageDisabled, (value) => {
    if (value) {
      sendMsg.value = "";
    }
  });
  const createMessage = (tim, message) => {
    return tim.createTextMessage({
      to: roomId.value,
      conversationType: TencentCloudChat.TYPES.CONV_GROUP,
      payload: {
        text: message
      }
    });
  };
  const createGiftMessage = (tim, giftMsg) => {
    const giftMsgString = JSON.stringify(giftMsg);
    return tim.createCustomMessage({
      to: roomId.value,
      conversationType: TencentCloudChat.TYPES.CONV_GROUP,
      payload: {
        data: giftMsgString,
        description: "",
        extension: ""
      }
    });
  };
  const sendMessage = async () => {
    var _a;
    try {
      let message;
      const tim = (_a = roomEngine.instance) == null ? void 0 : _a.getTIM();
      if (!tim) {
        throw new Error("tim is null");
      }
      let inputValue = decodeSendTextMsg(sendMsg.value);
      sendMsg.value = "";
      isEmojiToolbarVisible.value = false;
      if (inputValue === "") return;
      message = createMessage(tim, inputValue);
      await tim.sendMessage(message);
      chatStore.updateMessageList({
        ID: Math.random().toString(),
        type: "TIMTextElem",
        payload: {
          text: message.payload.text
        },
        nick: roomStore.localUser.nameCard || roomStore.localUser.userName || roomStore.localUser.userId,
        from: roomStore.localUser.userId,
        flow: "out",
        sequence: Math.random()
      });
    } catch (error) {
      renderMsg({ type: "error", message: t("Failed to send the message") });
    }
  };
  const sendGiftMsg = async (giftMsg) => {
    var _a;
    try {
      const tim = (_a = roomEngine.instance) == null ? void 0 : _a.getTIM();
      if (!tim) {
        throw new Error("tim is null");
      }
      const message = createGiftMessage(tim, giftMsg);
      await tim.sendMessage(message);
      chatStore.updateMessageList({
        ID: Math.random().toString(),
        type: "TIMTextElem",
        payload: {
          text: message.payload.data
        },
        nick: roomStore.localUser.nameCard || roomStore.localUser.userName || roomStore.localUser.userId,
        from: roomStore.localUser.userId,
        flow: "out",
        sequence: Math.random()
      });
    } catch (error) {
      renderMsg({ type: "error", message: t("Failed to send the gift") });
    }
  };
  const handleChooseEmoji = (emojiName) => {
    sendMsg.value += emojiName;
    editorInputEle.value.focus();
  };
  const togglePopover = () => {
    isEmojiToolbarVisible.value = !isEmojiToolbarVisible.value;
  };
  return {
    t,
    editorInputEle,
    sendMsg,
    isMessageDisabled,
    sendMessage,
    sendGiftMsg,
    handleChooseEmoji,
    isEmojiToolbarVisible,
    togglePopover
  };
}
export {
  useChatEditor as default
};
