import { defineComponent, ref, watch, nextTick, onMounted, onUnmounted, createElementBlock, openBlock, createElementVNode, createVNode, Fragment, renderList, unref, createCommentVNode, createBlock, toDisplayString } from "vue";
import { storeToRefs } from "pinia";
import { TUIRole } from "@tencentcloud/tuiroom-engine-js";
import AudienceLevel from "../../common/AudienceLevel.vue.mjs";
import MessageText from "../MessageTypes/MessageText.vue.mjs";
import GiftPlayerCardList from "../../Gift/GiftPlayerCardList.vue.mjs";
import useMessageList from "./useMessageListHook.mjs";
import { getScrollInfo } from "../../../utils/domOperation.mjs";
import { throttle } from "../../../utils/utils.mjs";
import { useRoomStore } from "../../../stores/room.mjs";
import { isGiftMsg } from "../util.mjs";
import { useI18n } from "../../../locales/index.mjs";
const _hoisted_1 = { class: "message-list-container" };
const _hoisted_2 = { class: "message-item-wrapper" };
const _hoisted_3 = ["title"];
const _hoisted_4 = {
  key: 1,
  class: "anchor-identity"
};
const _hoisted_5 = { class: "message-body" };
const _hoisted_6 = {
  key: 0,
  class: "audience-name"
};
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "MessageList",
  setup(__props) {
    const messageListRef = ref();
    const roomStore = useRoomStore();
    const { getDisplayName } = storeToRefs(roomStore);
    const { t } = useI18n();
    const {
      messageList,
      setMessageListInfo,
      handleGetHistoryMessageList,
      isCompleted
    } = useMessageList();
    let isScrollAtBottom = true;
    const isMessageFromAnchor = (from) => {
      return roomStore.getUserRole(from) === TUIRole.kRoomOwner;
    };
    const handleMessageListScroll = (e) => {
      const messageContainer = e.target;
      const bottom = messageContainer.scrollHeight - messageContainer.scrollTop - messageContainer.clientHeight;
      isScrollAtBottom = bottom <= 80;
      if (messageContainer.scrollTop < 40 && !isCompleted.value) {
        handleGetHistoryMessageList();
      }
    };
    const handleScroll = throttle(handleMessageListScroll, 1e3);
    async function scrollToLatestMessage() {
      const { scrollHeight } = await getScrollInfo("#messageScrollList");
      if (messageListRef.value) {
        messageListRef.value.scrollTop = scrollHeight;
      }
    }
    watch(messageList, async (newMessageList, oldMessageList) => {
      var _a;
      if (newMessageList.length === 0) return;
      const lastMessage = newMessageList.slice(-1);
      const oldLastMessage = oldMessageList.slice(-1);
      const isSendByMe = lastMessage[0].flow === "out";
      const isNewMessage = lastMessage[0].ID !== ((_a = oldLastMessage[0]) == null ? void 0 : _a.ID);
      await nextTick();
      if (isScrollAtBottom) {
        scrollToLatestMessage();
        return;
      }
      if (isSendByMe && isNewMessage) {
        scrollToLatestMessage();
      }
    });
    onMounted(() => {
      var _a;
      setMessageListInfo();
      (_a = messageListRef.value) == null ? void 0 : _a.addEventListener("scroll", handleScroll);
    });
    onUnmounted(() => {
      var _a;
      (_a = messageListRef.value) == null ? void 0 : _a.removeEventListener("scroll", handleScroll);
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1, [
        createElementVNode("div", {
          id: "messageScrollList",
          ref_key: "messageListRef",
          ref: messageListRef,
          class: "message-list"
        }, [
          (openBlock(true), createElementBlock(Fragment, null, renderList(unref(messageList), (item) => {
            return openBlock(), createElementBlock("div", {
              key: item.ID,
              ref_for: true,
              ref: "messageAimId",
              class: "message-item"
            }, [
              createElementVNode("div", _hoisted_2, [
                !unref(isGiftMsg)(item.payload.text) ? (openBlock(), createElementBlock("div", {
                  key: 0,
                  class: "message-header",
                  title: item.nick || item.from
                }, [
                  !isMessageFromAnchor(item.from) ? (openBlock(), createBlock(AudienceLevel, {
                    key: 0,
                    level: 0
                  })) : createCommentVNode("", true),
                  isMessageFromAnchor(item.from) ? (openBlock(), createElementBlock("div", _hoisted_4, toDisplayString(unref(t)("ANCHOR")), 1)) : createCommentVNode("", true)
                ], 8, _hoisted_3)) : createCommentVNode("", true),
                createElementVNode("div", _hoisted_5, [
                  !unref(isGiftMsg)(item.payload.text) ? (openBlock(), createElementBlock("span", _hoisted_6, toDisplayString(unref(getDisplayName)(item.from)) + " : ", 1)) : createCommentVNode("", true),
                  createVNode(MessageText, {
                    data: item.payload.text
                  }, null, 8, ["data"])
                ])
              ])
            ]);
          }), 128))
        ], 512),
        createVNode(GiftPlayerCardList, { class: "gift-card-player-area" })
      ]);
    };
  }
});
export {
  _sfc_main as default
};
