import { watch, onMounted, onUnmounted } from "vue";
import { storeToRefs } from "pinia";
import { TencentCloudChat } from "@tencentcloud/tuiroom-engine-js";
import { useChatStore } from "../../../stores/chat.mjs";
import { useBasicStore } from "../../../stores/basic.mjs";
import { useI18n } from "../../../locales/index.mjs";
import useGetRoomEngine from "../../../hooks/useRoomEngine.mjs";
import { isGiftMsg } from "../util.mjs";
import { useGiftCardManager, safelyParseGiftMsgForPlayerCard } from "../../Gift/useGiftPlayerCard.mjs";
function useMessageList() {
  const { t } = useI18n();
  const roomEngine = useGetRoomEngine();
  const chatStore = useChatStore();
  const basicStore = useBasicStore();
  const { roomId } = storeToRefs(basicStore);
  const { messageList, isCompleted, nextReqMessageId } = storeToRefs(chatStore);
  const giftCardManager = useGiftCardManager();
  const showGiftCard = (giftMsg) => {
    const giftData = safelyParseGiftMsgForPlayerCard(giftMsg);
    giftCardManager.show(giftData);
  };
  watch(
    isCompleted,
    (value) => {
      isCompleted.value = value;
    },
    { immediate: true, deep: true }
  );
  async function handleGetHistoryMessageList() {
    var _a;
    const tim = (_a = roomEngine.instance) == null ? void 0 : _a.getTIM();
    const imResponse = await (tim == null ? void 0 : tim.getMessageList({
      conversationID: `GROUP${roomId.value}`,
      nextReqMessageID: nextReqMessageId.value
    }));
    const {
      nextReqMessageID: middleReqMessageId,
      messageList: historyMessageList,
      isCompleted: isCompleted2
    } = imResponse.data;
    messageList.value.splice(0, 0, ...historyMessageList);
    const currentMessageList = messageList.value.filter(
      (item) => item.type === "TIMTextElem"
    );
    chatStore.setMessageListInfo(
      currentMessageList,
      isCompleted2,
      middleReqMessageId
    );
  }
  async function getMessageList() {
    var _a;
    let count = 0;
    const result = {
      currentMessageList: [],
      isCompleted: false,
      nextReqMessageId: ""
    };
    const tim = (_a = roomEngine.instance) == null ? void 0 : _a.getTIM();
    const getIMMessageList = async () => {
      const conversationData = {
        conversationID: `GROUP${roomId.value}`
      };
      if (result.nextReqMessageId !== "") {
        conversationData.nextReqMessageID = result.nextReqMessageId;
      }
      const imResponse = await (tim == null ? void 0 : tim.getMessageList(conversationData));
      const { messageList: messageList2, isCompleted: isCompleted2, nextReqMessageID } = imResponse.data;
      result.currentMessageList.splice(0, 0, ...messageList2);
      result.isCompleted = messageList2.length > 0 ? isCompleted2 : true;
      result.nextReqMessageId = nextReqMessageID;
      if (result.isCompleted || result.currentMessageList.length >= 15) {
        return;
      }
      count += 1;
      if (count === 1) {
        await getIMMessageList();
      }
    };
    await getIMMessageList();
    return result;
  }
  const onReceiveMessage = (options) => {
    if (!options || !options.data) {
      return;
    }
    const currentConversationId = `GROUP${roomId.value}`;
    options.data.forEach((message) => {
      var _a, _b, _c;
      if (message.conversationID !== currentConversationId || message.type !== TencentCloudChat.TYPES.MSG_TEXT && message.type !== TencentCloudChat.TYPES.MSG_CUSTOM) {
        return;
      }
      let text = "";
      const {
        ID,
        nick: userName,
        from: userId
      } = message;
      if (isGiftMsg((_a = message.payload) == null ? void 0 : _a.data)) {
        text = (_b = message.payload) == null ? void 0 : _b.data;
        showGiftCard(text);
      } else {
        text = (_c = message.payload) == null ? void 0 : _c.text;
      }
      chatStore.updateMessageList({
        ID,
        type: "TIMTextElem",
        payload: {
          text
        },
        nick: userName || userId,
        from: userId,
        flow: "in",
        sequence: Math.random()
      });
    });
  };
  async function setMessageListInfo() {
    const { currentMessageList, isCompleted: isCompleted2, nextReqMessageId: nextReqMessageId2 } = await getMessageList();
    const filterCurrentMessageList = currentMessageList.filter(
      (item) => item.type === "TIMTextElem"
    );
    chatStore.setMessageListInfo(
      filterCurrentMessageList,
      isCompleted2,
      nextReqMessageId2
    );
  }
  function getDisplaySenderName(index) {
    if (index === 0) return true;
    return messageList.value[index].from !== messageList.value[index - 1].from;
  }
  function registerEventListener() {
    var _a;
    const tim = (_a = roomEngine.instance) == null ? void 0 : _a.getTIM();
    if (tim) {
      tim.on(TencentCloudChat.EVENT.MESSAGE_RECEIVED, onReceiveMessage);
    } else {
      setTimeout(() => {
        registerEventListener();
      }, 1e3);
    }
  }
  onMounted(() => {
    registerEventListener();
  });
  onUnmounted(() => {
    var _a;
    const tim = (_a = roomEngine.instance) == null ? void 0 : _a.getTIM();
    tim == null ? void 0 : tim.off(TencentCloudChat.EVENT.MESSAGE_RECEIVED, onReceiveMessage);
  });
  return {
    t,
    handleGetHistoryMessageList,
    messageList,
    getMessageList,
    setMessageListInfo,
    getDisplaySenderName,
    isCompleted
  };
}
export {
  useMessageList as default
};
