import { defineComponent, ref, onMounted, onUnmounted, createElementBlock, createCommentVNode, unref, openBlock, createElementVNode, toDisplayString, createVNode, Fragment, renderList, normalizeClass } from "vue";
import { useGiftList } from "./useGiftList.mjs";
import WalletIcon from "../common/WalletIcon.vue.mjs";
import SvgIcon from "../common/base/SvgIcon.vue.mjs";
import renderMsg from "../common/base/Message/Message.mjs";
import { useRoomStore } from "../../stores/room.mjs";
import { useI18n } from "../../locales/index.mjs";
import { SingleRechargeAmount } from "../../constants/giftConfig.mjs";
const _hoisted_1 = {
  key: 0,
  class: "tui-gift-list"
};
const _hoisted_2 = { class: "gift-title" };
const _hoisted_3 = { class: "title" };
const _hoisted_4 = { class: "gift-item-area" };
const _hoisted_5 = ["onClick"];
const _hoisted_6 = { class: "img-wrapper" };
const _hoisted_7 = ["src", "alt"];
const _hoisted_8 = ["onClick"];
const _hoisted_9 = { class: "gift-price" };
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "GiftList",
  setup(__props) {
    const giftList = ref([]);
    const selectedGift = ref({});
    const { getGiftList, handleSendGift, getGiftName } = useGiftList();
    const { localUser, rechargeMoney, isAudience } = useRoomStore();
    const { t } = useI18n();
    const handleSelectGift = (gift) => {
      selectedGift.value = gift;
    };
    const handleSendSelectedGift = async (gift) => {
      if (selectedGift.value !== gift) return;
      try {
        await handleSendGift(gift);
        selectedGift.value = {};
      } catch (error) {
        renderMsg({
          type: "error",
          message: t("Insufficient balance, please recharge")
        });
        selectedGift.value = {};
      }
    };
    const handleRechargeMoney = () => {
      const result = rechargeMoney(localUser.userId, SingleRechargeAmount);
      if (result) {
        renderMsg({
          type: "success",
          message: t("Recharge successful")
        });
      } else {
        renderMsg({
          type: "error",
          message: t("Recharge failed")
        });
      }
    };
    onMounted(async () => {
      giftList.value = await getGiftList();
    });
    onUnmounted(() => {
      selectedGift.value = {};
    });
    return (_ctx, _cache) => {
      return unref(isAudience) ? (openBlock(), createElementBlock("div", _hoisted_1, [
        createElementVNode("div", _hoisted_2, [
          createElementVNode("span", _hoisted_3, toDisplayString(unref(t)("Gift")), 1),
          createElementVNode("span", {
            class: "recharge-button",
            onClick: handleRechargeMoney
          }, [
            createVNode(SvgIcon, {
              class: "recharge-icon",
              icon: WalletIcon
            }),
            createElementVNode("span", null, toDisplayString(`${unref(t)("Recharge")}(${unref(localUser).money})`), 1)
          ])
        ]),
        createElementVNode("div", _hoisted_4, [
          (openBlock(true), createElementBlock(Fragment, null, renderList(giftList.value, (item, index) => {
            return openBlock(), createElementBlock("div", {
              class: normalizeClass(["gift-item", { active: selectedGift.value === item }]),
              onClick: ($event) => handleSelectGift(item),
              key: index
            }, [
              createElementVNode("div", _hoisted_6, [
                createElementVNode("img", {
                  src: item.imageUrl,
                  alt: item.giftName
                }, null, 8, _hoisted_7)
              ]),
              createElementVNode("span", {
                class: "gift-name",
                onClick: ($event) => handleSendSelectedGift(item)
              }, toDisplayString(selectedGift.value === item ? unref(t)("Send") : unref(getGiftName)(item)), 9, _hoisted_8),
              createElementVNode("span", _hoisted_9, toDisplayString(item.price), 1)
            ], 10, _hoisted_5);
          }), 128))
        ])
      ])) : createCommentVNode("", true);
    };
  }
});
export {
  _sfc_main as default
};
