import { ref } from "vue";
import TUIRoomEngine, { TUIRoomEvents } from "@tencentcloud/tuiroom-engine-js";
import useGetRoomEngine from "../../../hooks/useRoomEngine.mjs";
import { useI18n } from "../../../locales/index.mjs";
const { t } = useI18n();
const roomEngine = useGetRoomEngine();
const isShowAutoPlayFailPrompt = ref(false);
const autoPlayFailPromptText = ref("");
const resumeFunction = ref(null);
const autoplayFailCallback = (callbackInfo) => {
  const { resume } = callbackInfo;
  if (!isShowAutoPlayFailPrompt.value) {
    isShowAutoPlayFailPrompt.value = true;
    autoPlayFailPromptText.value = t("Click page to resume audio/video play");
    resumeFunction.value = resume;
  }
};
const closeAutoPlayFailPrompt = () => {
  if (isShowAutoPlayFailPrompt.value) {
    if (resumeFunction.value && typeof resumeFunction.value === "function") {
      resumeFunction.value();
      resumeFunction.value = null;
    }
    isShowAutoPlayFailPrompt.value = false;
    autoPlayFailPromptText.value = "";
    cleanupAutoPlayListener();
  }
};
const cleanupAutoPlayListener = () => {
  var _a;
  (_a = roomEngine.instance) == null ? void 0 : _a.off(
    TUIRoomEvents.onAutoPlayFailed,
    autoplayFailCallback
  );
};
function useAutoPlayFailPrompt() {
  TUIRoomEngine.once("ready", () => {
    var _a;
    (_a = roomEngine.instance) == null ? void 0 : _a.on(
      TUIRoomEvents.onAutoPlayFailed,
      autoplayFailCallback
    );
  });
  return {
    isShowAutoPlayFailPrompt,
    autoPlayFailPromptText,
    closeAutoPlayFailPrompt
  };
}
export {
  useAutoPlayFailPrompt as default
};
