import { defineComponent, ref, watch, onUnmounted, createElementBlock, openBlock, createBlock, createCommentVNode, unref, createVNode } from "vue";
import { storeToRefs } from "pinia";
import TUIRoomEngine, { TUIRoomEvents, TUIVideoStreamType } from "@tencentcloud/tuiroom-engine-js";
import { useRoomStore } from "../../../stores/room.mjs";
import { useBasicStore } from "../../../stores/basic.mjs";
import { LAYOUT } from "../../../constants/render.mjs";
import StreamRegion from "../StreamRegion/StreamRegionPC.vue.mjs";
import logger from "../../../utils/common/logger/index.mjs";
import Avatar from "../../common/Avatar.vue2.mjs";
import AutoPlayFailPrompt from "../AutoPlayFailPrompt/index.vue.mjs";
import useGetRoomEngine from "../../../hooks/useRoomEngine.mjs";
import useAutoPlayFailPrompt from "../AutoPlayFailPrompt/useAutoPlayFailPrompt.mjs";
const _hoisted_1 = {
  id: "streamContainer",
  class: "tui-stream-container"
};
const _hoisted_2 = {
  key: 1,
  class: "avatar-region"
};
const logPrefix = "[StreamContainer]";
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "StreamContainer",
  setup(__props) {
    const roomEngine = useGetRoomEngine();
    const { isShowAutoPlayFailPrompt, autoPlayFailPromptText, closeAutoPlayFailPrompt } = useAutoPlayFailPrompt();
    const roomStore = useRoomStore();
    const { streamList } = storeToRefs(roomStore);
    const basicStore = useBasicStore();
    const { layout } = storeToRefs(basicStore);
    const enlargeStream = ref(streamList.value[0]);
    watch(
      () => streamList.value.length,
      (val) => {
        if (val === 1) {
          enlargeStream.value = streamList.value[0];
          return;
        }
      }
    );
    const onUserVideoStateChanged = (eventInfo) => {
      var _a;
      const { userId, streamType, hasVideo } = eventInfo;
      if (streamType === TUIVideoStreamType.kScreenStream) {
        if (hasVideo) {
          enlargeStream.value = userId === basicStore.userId ? roomStore.localScreenStream : roomStore.streamInfoObj[`${userId}_${streamType}`];
          if (enlargeStream.value && [LAYOUT.RIGHT_SIDE_LIST, LAYOUT.TOP_SIDE_LIST].indexOf(layout.value) === -1) {
            basicStore.setLayout(LAYOUT.RIGHT_SIDE_LIST);
          }
          if (userId !== basicStore.userId) {
            roomStore.setHasOtherScreenShare(true);
          }
        } else {
          if (userId === ((_a = enlargeStream.value) == null ? void 0 : _a.userId)) {
            handleLargeStreamLeave();
          }
          if (userId !== basicStore.userId) {
            roomStore.setHasOtherScreenShare(false);
          }
          logger.debug(
            `${logPrefix} onUserVideoStateChanged: stop`,
            userId,
            streamType
          );
        }
      }
    };
    const onSeatListChanged = (eventInfo) => {
      var _a;
      const { leftList } = eventInfo;
      const leftUserIdList = leftList.map((item) => item.userId);
      if (enlargeStream.value && leftUserIdList.includes((_a = enlargeStream.value) == null ? void 0 : _a.userId)) {
        handleLargeStreamLeave();
      }
    };
    const onRemoteUserLeaveRoom = (eventInfo) => {
      var _a;
      const {
        userInfo: { userId }
      } = eventInfo;
      if (userId === ((_a = enlargeStream.value) == null ? void 0 : _a.userId)) {
        handleLargeStreamLeave();
      }
    };
    const handleLargeStreamLeave = () => {
      if (roomStore.remoteStreamList.length === 0) {
        basicStore.setLayout(LAYOUT.NINE_EQUAL_POINTS);
        enlargeStream.value = null;
      } else {
        [enlargeStream.value] = roomStore.remoteStreamList;
      }
    };
    TUIRoomEngine.once("ready", () => {
      var _a, _b, _c;
      (_a = roomEngine.instance) == null ? void 0 : _a.on(
        TUIRoomEvents.onRemoteUserLeaveRoom,
        onRemoteUserLeaveRoom
      );
      (_b = roomEngine.instance) == null ? void 0 : _b.on(TUIRoomEvents.onSeatListChanged, onSeatListChanged);
      (_c = roomEngine.instance) == null ? void 0 : _c.on(
        TUIRoomEvents.onUserVideoStateChanged,
        onUserVideoStateChanged
      );
    });
    onUnmounted(() => {
      var _a, _b, _c;
      (_a = roomEngine.instance) == null ? void 0 : _a.off(
        TUIRoomEvents.onRemoteUserLeaveRoom,
        onRemoteUserLeaveRoom
      );
      (_b = roomEngine.instance) == null ? void 0 : _b.off(TUIRoomEvents.onSeatListChanged, onSeatListChanged);
      (_c = roomEngine.instance) == null ? void 0 : _c.off(
        TUIRoomEvents.onUserVideoStateChanged,
        onUserVideoStateChanged
      );
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1, [
        enlargeStream.value ? (openBlock(), createBlock(unref(StreamRegion), {
          key: 0,
          streamInfo: enlargeStream.value,
          isEnlarge: true,
          observerViewInVisible: true,
          isNeedPlayStream: true
        }, null, 8, ["streamInfo"])) : (openBlock(), createElementBlock("div", _hoisted_2, [
          createVNode(Avatar, { class: "avatar" })
        ])),
        unref(isShowAutoPlayFailPrompt) ? (openBlock(), createBlock(AutoPlayFailPrompt, {
          key: 2,
          text: unref(autoPlayFailPromptText),
          onClose: unref(closeAutoPlayFailPrompt)
        }, null, 8, ["text", "onClose"])) : createCommentVNode("", true)
      ]);
    };
  }
});
export {
  _sfc_main as default
};
