import { defineComponent, ref, watch, onMounted, createElementBlock, openBlock, createVNode, createElementVNode, toDisplayString } from "vue";
import SvgIcon from "./base/SvgIcon.vue.mjs";
import DiamondIcon from "./icons/DiamondIcon.vue.mjs";
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "AudienceLevel",
  props: {
    level: {}
  },
  setup(__props) {
    const audienceLevelElement = ref(null);
    const props = __props;
    const colorLevelMap = {
      color_level_1: "#008FB2",
      color_level_2: "#2B6AD6",
      color_level_3: "#693CF0",
      color_level_4: "#C22F56"
    };
    const getLevelColor = (level) => {
      if (level >= 0 && level < 25) {
        return colorLevelMap.color_level_1;
      } else if (level >= 25 && level < 50) {
        return colorLevelMap.color_level_2;
      } else if (level >= 50 && level < 75) {
        return colorLevelMap.color_level_3;
      } else if (level >= 75 && level < 100) {
        return colorLevelMap.color_level_4;
      } else {
        return colorLevelMap.color_level_1;
      }
    };
    const updateBackgroundColor = (level) => {
      if (!audienceLevelElement.value) return;
      audienceLevelElement.value.style.setProperty("background-color", getLevelColor(level));
    };
    watch(() => props.level, () => {
      updateBackgroundColor(props.level);
    }, { immediate: true });
    onMounted(() => {
      updateBackgroundColor(props.level);
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("span", {
        ref_key: "audienceLevelElement",
        ref: audienceLevelElement,
        class: "audience-level"
      }, [
        createVNode(SvgIcon, {
          class: "svg-icon",
          icon: DiamondIcon
        }),
        createElementVNode("span", null, toDisplayString(props.level), 1)
      ], 512);
    };
  }
});
export {
  _sfc_main as default
};
