import { Ref, ComputedRef } from 'vue';
import { TUIRoomInfo, TUIVideoStreamType, TUIRequest } from '@tencentcloud/tuiroom-engine-js';
import { RoomState, UserInfo, StreamInfo } from '../type';
import { Comparator } from '../../utils/utils';

export declare function setRoomState(state: RoomState): void;
export declare function setRoomInfo(data: Partial<TUIRoomInfo>): void;
export declare function setLocalUser(options: {
    userId: string;
}): void;
export declare function addUserInfo(userInfo: Pick<UserInfo, 'userId'> & Partial<UserInfo>): void;
export declare function updateUserInfo(userInfo: Pick<UserInfo, 'userId'> & Partial<UserInfo>): void;
declare function removeUserInfo(userId: string): void;
declare function getUserInfo(options: {
    userId: string;
}): UserInfo;
declare function addStreamInfo(userId: string, streamType: TUIVideoStreamType): void;
declare function updateStreamInfo(streamInfo: Pick<StreamInfo, 'userId' | 'streamType'> & Partial<StreamInfo>): void;
declare function removeStreamInfo(userId: string, streamType: TUIVideoStreamType): void;
declare function addSeatApplicationRequest(request: TUIRequest): void;
declare function removeSeatApplicationRequest(request: TUIRequest): void;
declare function setSeatInvitationRequest(request: TUIRequest | null): void;
declare function reset(): void;
export default function useStore(options?: {
    sortUserBy: Comparator<UserInfo>;
    sortStreamBy: Comparator<StreamInfo>;
}): {
    store: {
        roomId: string;
        roomState: RoomState;
        roomInfo: any;
        setRoomInfo: typeof setRoomInfo;
        userInfoObj: Record<string, UserInfo>;
        userList: UserInfo[];
        localUser: UserInfo;
        remoteUserList: UserInfo[];
        streamInfoObj: Record<string, StreamInfo>;
        localStream: StreamInfo;
        onSeatUserList: UserInfo[];
        applyToOnSeatUserList: UserInfo[];
        userSearchText: string;
        seatApplicationRequestList: TUIRequest[];
        seatInvitationRequest: any;
        setLocalUser: typeof setLocalUser;
        addUserInfo: typeof addUserInfo;
        updateUserInfo: typeof updateUserInfo;
        getUserInfo: typeof getUserInfo;
        removeUserInfo: typeof removeUserInfo;
        addStreamInfo: typeof addStreamInfo;
        updateStreamInfo: typeof updateStreamInfo;
        removeStreamInfo: typeof removeStreamInfo;
        reset: typeof reset;
        addSeatApplicationRequest: typeof addSeatApplicationRequest;
        removeSeatApplicationRequest: typeof removeSeatApplicationRequest;
        setSeatInvitationRequest: typeof setSeatInvitationRequest;
    };
    roomId: Ref<string, string>;
    roomState: Ref<RoomState, RoomState>;
    roomInfo: Ref<any, any>;
    userInfoObj: Ref<Record<string, UserInfo>, Record<string, UserInfo>>;
    userList: ComputedRef<UserInfo[]>;
    localUser: ComputedRef<UserInfo>;
    remoteUserList: ComputedRef<UserInfo[]>;
    streamInfoObj: Ref<Record<string, StreamInfo>, Record<string, StreamInfo>>;
    localStream: ComputedRef<StreamInfo>;
    onSeatUserList: ComputedRef<UserInfo[]>;
    applyToOnSeatUserList: ComputedRef<UserInfo[]>;
    userSearchText: Ref<string, string>;
    seatApplicationRequestList: Ref<TUIRequest[], TUIRequest[]>;
    seatInvitationRequest: Ref<any, any>;
};
export {};
