import { defineComponent, ref, onMounted, onUnmounted, watch, resolveComponent, createBlock, createElementBlock, openBlock, createElementVNode, createVNode, unref, withDirectives, createCommentVNode, normalizeClass, withModifiers, withCtx, createTextVNode, toDisplayString } from "vue";
import _imports_0 from "./assets/imgs/logo.png.mjs";
import RoomContent from "./components/RoomContent/index.vue.mjs";
import Chat from "./components/Chat/index.vue.mjs";
import { debounce, throttle } from "./utils/utils.mjs";
import { isWeChat, isMobile } from "./utils/environment.mjs";
import vTap from "./directives/vTap.mjs";
import { TUIRole, TUIErrorCode } from "@tencentcloud/tuiroom-engine-js";
import { TUIButton } from "@tencentcloud/uikit-base-component-vue3";
import { useRoomStore } from "./stores/room.mjs";
import UserInfo from "./components/RoomHeader/UserInfo/index.mjs";
import LoadingOverlay from "./components/PreRoom/LoadingOverlay.vue.mjs";
import MessageBox from "./components/common/base/MessageBox/index.mjs";
import renderMsg from "./components/common/base/Message/Message.mjs";
import useTRTCDetect from "./hooks/useTRTCDetect.mjs";
import AnchorInfo from "./components/AnchorInfo/AnchorInfo.vue.mjs";
import AudienceList from "./components/AudienceList/AudienceList.vue.mjs";
import AudienceListH5 from "./components/AudienceList/AudienceListH5.vue.mjs";
import GiftList from "./components/Gift/GiftList.vue.mjs";
import GiftListPopupPC from "./components/Gift/GiftPopupList.vue.mjs";
import GiftMore from "./components/Gift/GiftMore.vue.mjs";
import CloseIcon from "./components/common/icons/CloseIcon.vue.mjs";
import ShareLink from "./components/ShareLink/ShareLink.vue.mjs";
import _sfc_main$1 from "./core/components/AudioSetting/index.vue.mjs";
import VideoSetting from "./core/components/VideoSetting/index.vue.mjs";
import { roomService } from "./services/roomService.mjs";
import { EventType } from "./services/types.mjs";
import "./locales/index.mjs";
import "mitt";
import "./services/manager/roomActionManager.mjs";
import useDeviceManager from "./hooks/useDeviceManager.mjs";
import vClickOutside from "./directives/vClickOutside.mjs";
import { createGiftCardManager } from "./components/Gift/useGiftPlayerCard.mjs";
import { storeToRefs } from "pinia";
import "./core/hooks/useAudioDeviceState/index.mjs";
import "./core/hooks/useVideoDeviceState/index.mjs";
import "./core/hooks/useUserState/useUserActions/useAudioAction.mjs";
import "./core/hooks/useUserState/useUserActions/useChatAction.mjs";
import "./core/hooks/useUserState/useUserActions/useVideoAction.mjs";
import "./core/hooks/useUserState/useUserActions/useTransferOwnerAction.mjs";
import "./core/hooks/useUserState/useUserActions/useChangeNameCardAction/index.mjs";
import "./core/hooks/useUserState/useUserActions/useKickUserAction.mjs";
import "./core/hooks/useUserState/useUserActions/useSeatAction.mjs";
import "./core/hooks/useUserState/useUserActions/useAdminAction.mjs";
import "./core/store/room.mjs";
import "./hooks/useRoomEngine.mjs";
import "./core/manager/userEventManger.mjs";
import { MediaSettingDisplayMode } from "./core/type/MediaDeviceSetting.mjs";
/* empty css                                               */
/* empty css                                          */
/* empty css                              */
import "./stores/basic.mjs";
/* empty css                                             */
import "./core/hooks/useUserState/useUserActions/useMemberInviteAction.mjs";
/* empty css                                               */
/* empty css                                                 */
/* empty css                                                 */
/* empty css                                      */
/* empty css                                      */
/* empty css                                           */
/* empty css                                                       */
/* empty css                                                     */
/* empty css                                                     */
/* empty css                                    */
const _hoisted_1 = { class: "live-header" };
const _hoisted_2 = { class: "top-right-operator-h5" };
const _hoisted_3 = { class: "live-body" };
const _hoisted_4 = { class: "live-content" };
const _hoisted_5 = {
  key: 0,
  class: "tui-live-gift-area"
};
const _hoisted_6 = {
  key: 1,
  class: "tui-live-anchor-controls"
};
const _hoisted_7 = { class: "live-audio-video-setting" };
const _hoisted_8 = { class: "live-end-live-button" };
const _hoisted_9 = { class: "live-interactive" };
const _hoisted_10 = {
  key: 0,
  class: "tui-live-audience-list"
};
const _hoisted_11 = { class: "tui-live-chat" };
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "liveMainView",
  props: {
    userInfo: {}
  },
  emits: [
    "on-log-out",
    "on-create-room",
    "on-enter-room",
    "on-exit-room",
    "on-destroy-room",
    "on-kicked-out-of-room",
    "on-kicked-off-line",
    "on-userSig-expired"
  ],
  setup(__props, { expose: __expose, emit: __emit }) {
    const roomEngine = useRoomStore();
    const { getUserRole } = roomEngine;
    const { isAnchor, isAudience } = storeToRefs(roomEngine);
    const isShowPasswordContainer = ref(false);
    const isShowLoading = ref(true);
    const isDisplayGiftList = ref(false);
    createGiftCardManager();
    useTRTCDetect();
    useDeviceManager({ listenForDeviceChange: true });
    const { t } = roomService;
    __expose({
      init,
      createRoom,
      enterRoom,
      dismissRoom,
      leaveRoom,
      resetStore,
      t
    });
    const emit = __emit;
    const handleOpenMoreGiftList = () => {
      isDisplayGiftList.value = !isDisplayGiftList.value;
    };
    const handleClickOutside = () => {
      isDisplayGiftList.value = false;
    };
    const handleEndLiving = () => {
      roomService.dismissRoom();
    };
    const showMessageBox = (data) => {
      const {
        message,
        title = roomService.t("Note"),
        duration,
        cancelButtonText,
        confirmButtonText = roomService.t("Sure"),
        callback = () => {
        }
      } = data;
      MessageBox({
        title,
        message,
        duration,
        cancelButtonText,
        confirmButtonText,
        callback
      });
    };
    const showMessage = (data) => {
      const { type, message, duration } = data;
      renderMsg({
        type,
        message,
        duration
      });
    };
    onMounted(() => {
      roomService.on(EventType.ROOM_NOTICE_MESSAGE, showMessage);
      roomService.on(EventType.ROOM_NOTICE_MESSAGE_BOX, showMessageBox);
      roomService.on(EventType.KICKED_OUT, onKickedOutOfRoom);
      roomService.on(EventType.USER_SIG_EXPIRED, onUserSigExpired);
      roomService.on(EventType.KICKED_OFFLINE, onKickedOffLine);
      roomService.on(EventType.ROOM_START, onStartRoom);
      roomService.on(EventType.ROOM_JOIN, onJoinRoom);
      roomService.on(EventType.ROOM_LEAVE, onLeaveRoom);
      roomService.on(EventType.ROOM_DISMISS, onDismissRoom);
      roomService.on(EventType.USER_LOGOUT, onLogout);
      roomService.on(EventType.ROOM_NEED_PASSWORD, onRoomNeedPassword);
    });
    onUnmounted(() => {
      roomService.off(EventType.ROOM_NOTICE_MESSAGE, showMessage);
      roomService.off(EventType.ROOM_NOTICE_MESSAGE_BOX, showMessageBox);
      roomService.off(EventType.KICKED_OUT, onKickedOutOfRoom);
      roomService.off(EventType.USER_SIG_EXPIRED, onUserSigExpired);
      roomService.off(EventType.KICKED_OFFLINE, onKickedOffLine);
      roomService.off(EventType.ROOM_START, onStartRoom);
      roomService.off(EventType.ROOM_JOIN, onJoinRoom);
      roomService.off(EventType.ROOM_LEAVE, onLeaveRoom);
      roomService.off(EventType.ROOM_DISMISS, onDismissRoom);
      roomService.off(EventType.USER_LOGOUT, onLogout);
      roomService.off(EventType.ROOM_NEED_PASSWORD, onRoomNeedPassword);
      roomService.resetStore();
    });
    const roomContentRef = ref();
    const showRoomTool = ref(true);
    const roomRef = ref();
    function handleHideRoomTool() {
      showRoomTool.value = false;
    }
    watch(
      () => roomRef.value,
      (newValue, oldValue) => {
        if (!isWeChat && !isMobile) {
          if (newValue) {
            addRoomContainerEvent(newValue);
          } else {
            oldValue && removeRoomContainerEvent(oldValue);
          }
        }
      }
    );
    const handleHideRoomToolDebounce = debounce(handleHideRoomTool, 5e3);
    const handleHideRoomToolThrottle = throttle(handleHideRoomToolDebounce, 1e3);
    const showTool = () => {
      showRoomTool.value = true;
      handleHideRoomToolDebounce();
    };
    const showToolThrottle = () => {
      showRoomTool.value = true;
      handleHideRoomToolThrottle();
    };
    const hideTool = () => {
      handleHideRoomTool();
    };
    const addRoomContainerEvent = (container) => {
      container.addEventListener("mouseenter", showTool);
      container.addEventListener("click", showTool);
      container.addEventListener("mousemove", showToolThrottle);
      container.addEventListener("mouseleave", hideTool);
    };
    const removeRoomContainerEvent = (container) => {
      container.removeEventListener("mouseenter", showTool);
      container.removeEventListener("click", showTool);
      container.removeEventListener("mousemove", showToolThrottle);
      container.removeEventListener("mouseleave", hideTool);
    };
    function handleRoomContentTap() {
      showRoomTool.value = !showRoomTool.value;
      if (showRoomTool.value) {
        handleHideRoomToolDebounce();
      }
    }
    async function dismissRoom() {
      await roomService.dismissRoom();
    }
    async function leaveRoom() {
      const userRole = getUserRole(__props.userInfo.userId);
      if (userRole === TUIRole.kRoomOwner) {
        await roomService.dismissRoom();
      } else {
        await roomService.leaveRoom();
      }
    }
    async function init(option) {
      await roomService.initRoomKit(option);
    }
    async function createRoom(options) {
      const { roomId, roomName, roomParam } = options;
      roomService.createRoom({
        roomId,
        roomName,
        roomParam
      });
    }
    async function enterRoom(options) {
      await roomService.enterRoom(options);
    }
    function onRoomNeedPassword(code) {
      if (code === TUIErrorCode.ERR_NEED_PASSWORD) {
        isShowPasswordContainer.value = true;
      }
    }
    function resetStore() {
      roomService.resetStore();
    }
    const logout = async () => {
      const userRole = getUserRole(__props.userInfo.userId);
      if (userRole === TUIRole.kRoomOwner) {
        await roomService.dismissRoom();
      } else if (userRole === TUIRole.kGeneralUser) {
        await roomService.leaveRoom();
      }
      roomService.logout();
    };
    const onStartRoom = () => {
      isShowLoading.value = false;
      emit("on-create-room", { code: 0, message: "create room" });
    };
    const onJoinRoom = () => {
      isShowLoading.value = false;
      isShowPasswordContainer.value = false;
      emit("on-enter-room", { code: 0, message: "enter room" });
    };
    const onLeaveRoom = async () => {
      emit("on-exit-room", { code: 0, message: "exit room" });
    };
    const onDismissRoom = () => {
      emit("on-destroy-room", { code: 0, message: "destroy room" });
    };
    const onLogout = () => {
      emit("on-log-out", { code: 0, message: "user logout" });
    };
    const onKickedOutOfRoom = async (eventInfo) => {
      const { roomId, reason, message } = eventInfo;
      emit("on-kicked-out-of-room", { roomId, reason, message });
    };
    const onUserSigExpired = () => {
      emit("on-userSig-expired");
    };
    const onKickedOffLine = (eventInfo) => {
      const { message } = eventInfo;
      emit("on-kicked-off-line", { message });
    };
    return (_ctx, _cache) => {
      const _component_SvgIcon = resolveComponent("SvgIcon");
      return isShowLoading.value ? (openBlock(), createBlock(LoadingOverlay, { key: 0 })) : (openBlock(), createElementBlock("div", {
        key: 1,
        id: "liveContainer",
        ref_key: "roomRef",
        ref: roomRef,
        class: "tui-live-container"
      }, [
        createElementVNode("div", _hoisted_1, [
          _cache[0] || (_cache[0] = createElementVNode("img", {
            class: "logo",
            src: _imports_0,
            alt: "logo"
          }, null, -1)),
          createVNode(unref(UserInfo), {
            class: "user-info",
            "user-id": _ctx.userInfo.userId,
            "user-name": _ctx.userInfo.userName || _ctx.userInfo.userId,
            "avatar-url": _ctx.userInfo.avatarUrl,
            onLogOut: logout
          }, null, 8, ["user-id", "user-name", "avatar-url"]),
          createElementVNode("div", _hoisted_2, [
            createVNode(AudienceListH5),
            createVNode(_component_SvgIcon, {
              class: "svg-icon",
              icon: CloseIcon,
              onClick: leaveRoom
            })
          ])
        ]),
        createElementVNode("div", _hoisted_3, [
          createElementVNode("div", _hoisted_4, [
            createVNode(AnchorInfo, { class: "anchor-info-area" }),
            withDirectives(createVNode(RoomContent, {
              ref_key: "roomContentRef",
              ref: roomContentRef,
              class: "tui-live-stream-content"
            }, null, 512), [
              [
                unref(vTap),
                handleRoomContentTap,
                void 0,
                { lazy: true }
              ]
            ]),
            unref(isAudience) ? withDirectives((openBlock(), createElementBlock("div", _hoisted_5, [
              createVNode(GiftList, {
                class: normalizeClass(["gift-list", isDisplayGiftList.value ? "display-gift-list-h5" : ""])
              }, null, 8, ["class"]),
              createVNode(GiftListPopupPC, {
                class: normalizeClass(["gift-list-popup", { "display-gift-list-popup": isDisplayGiftList.value }])
              }, null, 8, ["class"]),
              createVNode(GiftMore, {
                class: "gift-more",
                onClick: handleOpenMoreGiftList
              })
            ])), [
              [unref(vClickOutside), handleClickOutside]
            ]) : createCommentVNode("", true),
            unref(isAnchor) ? (openBlock(), createElementBlock("div", _hoisted_6, [
              createElementVNode("div", _hoisted_7, [
                createVNode(_sfc_main$1, {
                  displayMode: unref(MediaSettingDisplayMode).Icon
                }, null, 8, ["displayMode"]),
                createVNode(VideoSetting, {
                  displayMode: unref(MediaSettingDisplayMode).Icon
                }, null, 8, ["displayMode"])
              ]),
              createElementVNode("div", _hoisted_8, [
                createVNode(unref(TUIButton), {
                  size: "big",
                  type: "primary",
                  color: "red",
                  onClick: withModifiers(handleEndLiving, ["stop"])
                }, {
                  default: withCtx(() => [
                    createTextVNode(toDisplayString(unref(t)("End Living")), 1)
                  ]),
                  _: 1
                })
              ])
            ])) : createCommentVNode("", true),
            createVNode(ShareLink, { class: "tui-share-link-button" })
          ]),
          createElementVNode("div", _hoisted_9, [
            !isShowLoading.value ? (openBlock(), createElementBlock("div", _hoisted_10, [
              createVNode(AudienceList)
            ])) : createCommentVNode("", true),
            createElementVNode("div", _hoisted_11, [
              createVNode(Chat)
            ])
          ])
        ])
      ], 512));
    };
  }
});
export {
  _sfc_main as default
};
