import { isWeChat } from "./environment.mjs";
function debounce(fn, delay) {
  let timer;
  return function(...args) {
    if (timer > 0) {
      clearTimeout(timer);
    }
    timer = setTimeout(() => {
      fn.apply(this, args);
      timer = -1;
    }, delay);
  };
}
function throttle(fn, delay) {
  let previousTime = 0;
  return function(...args) {
    const now = Date.now();
    if (now - previousTime > delay) {
      fn.apply(this, args);
      previousTime = now;
    }
  };
}
function getUrlParam(key) {
  const url = window == null ? void 0 : window.location.href.replace(/^[^?]*\?/, "");
  const regexp = new RegExp(`(^|&)${key}=([^&#]*)(&|$|)`, "i");
  const paramMatch = url == null ? void 0 : url.match(regexp);
  return paramMatch ? paramMatch[2] : null;
}
const isUndefined = (value) => typeof value === "undefined";
const isNumber = (value) => typeof value === "number";
const isStringNumber = (value) => typeof value === "string" && !isNaN(Number(value));
const isFunction = (value) => typeof value === "function";
function addSuffix(value, suffix = "px") {
  if (isNumber(value) || isStringNumber(value)) {
    return value + suffix;
  }
  return value;
}
function getUrlWithRoomId(roomId) {
  if (isWeChat) return "";
  const currentUrl = window.location.href;
  const urlObj = new URL(currentUrl);
  const params = new URLSearchParams(urlObj.search);
  if (params.has("roomId")) {
    params.delete("roomId");
  }
  params.append("roomId", roomId);
  return `${`${urlObj.origin + urlObj.pathname}#/home?${params.toString()}`}`;
}
function getNanoId(size = 21) {
  const urlAlphabet = "useandom-26T198340PX75pxJACKVERYMINDBUSHWOLF_GQZbfghjklqvwyzrict";
  let id = "";
  let i = size;
  while (i) {
    id += urlAlphabet[Math.random() * 64 | 0];
    i = i - 1;
  }
  return id;
}
const combineComparators = (...comparators) => {
  return (a, b) => {
    for (const comparator of comparators) {
      const result = comparator(a, b);
      if (result !== 0) return result;
    }
    return 0;
  };
};
const createComparator = (compareRules) => {
  return (a, b) => {
    if (compareRules(a, b) && compareRules(b, a)) {
      return 0;
    }
    if (compareRules(a, b)) {
      return -1;
    }
    if (compareRules(b, a)) {
      return 1;
    }
    return 0;
  };
};
export {
  addSuffix,
  combineComparators,
  createComparator,
  debounce,
  getNanoId,
  getUrlParam,
  getUrlWithRoomId,
  isFunction,
  isNumber,
  isStringNumber,
  isUndefined,
  throttle
};
