"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const Vue = require("vue");
const pinia = require("pinia");
const TUIRoomEngine = require("@tencentcloud/tuiroom-engine-js");
const Message = require("../../common/base/Message/Message.js");
const useRoomEngine = require("../../../hooks/useRoomEngine.js");
const chat = require("../../../stores/chat.js");
const room = require("../../../stores/room.js");
const index = require("../../../locales/index.js");
const basic = require("../../../stores/basic.js");
const util = require("../util.js");
function useChatEditor() {
  const roomEngine = useRoomEngine.default();
  const basicStore = basic.useBasicStore();
  const chatStore = chat.useChatStore();
  const roomStore = room.useRoomStore();
  const { t } = index.useI18n();
  const { roomId } = pinia.storeToRefs(basicStore);
  const { isMessageDisabled } = pinia.storeToRefs(chatStore);
  const editorInputEle = Vue.ref();
  const sendMsg = Vue.ref("");
  const isEmojiToolbarVisible = Vue.ref(false);
  Vue.watch(isMessageDisabled, (value) => {
    if (value) {
      sendMsg.value = "";
    }
  });
  const createMessage = (tim, message) => {
    return tim.createTextMessage({
      to: roomId.value,
      conversationType: TUIRoomEngine.TencentCloudChat.TYPES.CONV_GROUP,
      payload: {
        text: message
      }
    });
  };
  const createGiftMessage = (tim, giftMsg) => {
    const giftMsgString = JSON.stringify(giftMsg);
    return tim.createCustomMessage({
      to: roomId.value,
      conversationType: TUIRoomEngine.TencentCloudChat.TYPES.CONV_GROUP,
      payload: {
        data: giftMsgString,
        description: "",
        extension: ""
      }
    });
  };
  const sendMessage = async () => {
    var _a;
    try {
      let message;
      const tim = (_a = roomEngine.instance) == null ? void 0 : _a.getTIM();
      if (!tim) {
        throw new Error("tim is null");
      }
      let inputValue = util.decodeSendTextMsg(sendMsg.value);
      sendMsg.value = "";
      isEmojiToolbarVisible.value = false;
      if (inputValue === "") return;
      message = createMessage(tim, inputValue);
      await tim.sendMessage(message);
      chatStore.updateMessageList({
        ID: Math.random().toString(),
        type: "TIMTextElem",
        payload: {
          text: message.payload.text
        },
        nick: roomStore.localUser.nameCard || roomStore.localUser.userName || roomStore.localUser.userId,
        from: roomStore.localUser.userId,
        flow: "out",
        sequence: Math.random()
      });
    } catch (error) {
      Message.default({ type: "error", message: t("Failed to send the message") });
    }
  };
  const sendGiftMsg = async (giftMsg) => {
    var _a;
    try {
      const tim = (_a = roomEngine.instance) == null ? void 0 : _a.getTIM();
      if (!tim) {
        throw new Error("tim is null");
      }
      const message = createGiftMessage(tim, giftMsg);
      await tim.sendMessage(message);
      chatStore.updateMessageList({
        ID: Math.random().toString(),
        type: "TIMTextElem",
        payload: {
          text: message.payload.data
        },
        nick: roomStore.localUser.nameCard || roomStore.localUser.userName || roomStore.localUser.userId,
        from: roomStore.localUser.userId,
        flow: "out",
        sequence: Math.random()
      });
    } catch (error) {
      Message.default({ type: "error", message: t("Failed to send the gift") });
    }
  };
  const handleChooseEmoji = (emojiName) => {
    sendMsg.value += emojiName;
    editorInputEle.value.focus();
  };
  const togglePopover = () => {
    isEmojiToolbarVisible.value = !isEmojiToolbarVisible.value;
  };
  return {
    t,
    editorInputEle,
    sendMsg,
    isMessageDisabled,
    sendMessage,
    sendGiftMsg,
    handleChooseEmoji,
    isEmojiToolbarVisible,
    togglePopover
  };
}
exports.default = useChatEditor;
