"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const Vue = require("vue");
const pinia = require("pinia");
const TUIRoomEngine = require("@tencentcloud/tuiroom-engine-js");
const AudienceLevel = require("../../common/AudienceLevel.vue.js");
const MessageText = require("../MessageTypes/MessageText.vue.js");
const GiftPlayerCardList = require("../../Gift/GiftPlayerCardList.vue.js");
const useMessageListHook = require("./useMessageListHook.js");
const domOperation = require("../../../utils/domOperation.js");
const utils = require("../../../utils/utils.js");
const room = require("../../../stores/room.js");
const util = require("../util.js");
const index = require("../../../locales/index.js");
const _hoisted_1 = { class: "message-list-container" };
const _hoisted_2 = { class: "message-item-wrapper" };
const _hoisted_3 = ["title"];
const _hoisted_4 = {
  key: 1,
  class: "anchor-identity"
};
const _hoisted_5 = { class: "message-body" };
const _hoisted_6 = {
  key: 0,
  class: "audience-name"
};
const _sfc_main = /* @__PURE__ */ Vue.defineComponent({
  __name: "MessageList",
  setup(__props) {
    const messageListRef = Vue.ref();
    const roomStore = room.useRoomStore();
    const { getDisplayName } = pinia.storeToRefs(roomStore);
    const { t } = index.useI18n();
    const {
      messageList,
      setMessageListInfo,
      handleGetHistoryMessageList,
      isCompleted
    } = useMessageListHook.default();
    let isScrollAtBottom = true;
    const isMessageFromAnchor = (from) => {
      return roomStore.getUserRole(from) === TUIRoomEngine.TUIRole.kRoomOwner;
    };
    const handleMessageListScroll = (e) => {
      const messageContainer = e.target;
      const bottom = messageContainer.scrollHeight - messageContainer.scrollTop - messageContainer.clientHeight;
      isScrollAtBottom = bottom <= 80;
      if (messageContainer.scrollTop < 40 && !isCompleted.value) {
        handleGetHistoryMessageList();
      }
    };
    const handleScroll = utils.throttle(handleMessageListScroll, 1e3);
    async function scrollToLatestMessage() {
      const { scrollHeight } = await domOperation.getScrollInfo("#messageScrollList");
      if (messageListRef.value) {
        messageListRef.value.scrollTop = scrollHeight;
      }
    }
    Vue.watch(messageList, async (newMessageList, oldMessageList) => {
      var _a;
      if (newMessageList.length === 0) return;
      const lastMessage = newMessageList.slice(-1);
      const oldLastMessage = oldMessageList.slice(-1);
      const isSendByMe = lastMessage[0].flow === "out";
      const isNewMessage = lastMessage[0].ID !== ((_a = oldLastMessage[0]) == null ? void 0 : _a.ID);
      await Vue.nextTick();
      if (isScrollAtBottom) {
        scrollToLatestMessage();
        return;
      }
      if (isSendByMe && isNewMessage) {
        scrollToLatestMessage();
      }
    });
    Vue.onMounted(() => {
      var _a;
      setMessageListInfo();
      (_a = messageListRef.value) == null ? void 0 : _a.addEventListener("scroll", handleScroll);
    });
    Vue.onUnmounted(() => {
      var _a;
      (_a = messageListRef.value) == null ? void 0 : _a.removeEventListener("scroll", handleScroll);
    });
    return (_ctx, _cache) => {
      return Vue.openBlock(), Vue.createElementBlock("div", _hoisted_1, [
        Vue.createElementVNode("div", {
          id: "messageScrollList",
          ref_key: "messageListRef",
          ref: messageListRef,
          class: "message-list"
        }, [
          (Vue.openBlock(true), Vue.createElementBlock(Vue.Fragment, null, Vue.renderList(Vue.unref(messageList), (item) => {
            return Vue.openBlock(), Vue.createElementBlock("div", {
              key: item.ID,
              ref_for: true,
              ref: "messageAimId",
              class: "message-item"
            }, [
              Vue.createElementVNode("div", _hoisted_2, [
                !Vue.unref(util.isGiftMsg)(item.payload.text) ? (Vue.openBlock(), Vue.createElementBlock("div", {
                  key: 0,
                  class: "message-header",
                  title: item.nick || item.from
                }, [
                  !isMessageFromAnchor(item.from) ? (Vue.openBlock(), Vue.createBlock(AudienceLevel.default, {
                    key: 0,
                    level: 0
                  })) : Vue.createCommentVNode("", true),
                  isMessageFromAnchor(item.from) ? (Vue.openBlock(), Vue.createElementBlock("div", _hoisted_4, Vue.toDisplayString(Vue.unref(t)("ANCHOR")), 1)) : Vue.createCommentVNode("", true)
                ], 8, _hoisted_3)) : Vue.createCommentVNode("", true),
                Vue.createElementVNode("div", _hoisted_5, [
                  !Vue.unref(util.isGiftMsg)(item.payload.text) ? (Vue.openBlock(), Vue.createElementBlock("span", _hoisted_6, Vue.toDisplayString(Vue.unref(getDisplayName)(item.from)) + " : ", 1)) : Vue.createCommentVNode("", true),
                  Vue.createVNode(MessageText.default, {
                    data: item.payload.text
                  }, null, 8, ["data"])
                ])
              ])
            ]);
          }), 128))
        ], 512),
        Vue.createVNode(GiftPlayerCardList.default, { class: "gift-card-player-area" })
      ]);
    };
  }
});
exports.default = _sfc_main;
