"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const Vue = require("vue");
const useGiftList = require("./useGiftList.js");
const WalletIcon = require("../common/WalletIcon.vue.js");
const SvgIcon = require("../common/base/SvgIcon.vue.js");
const Message = require("../common/base/Message/Message.js");
const room = require("../../stores/room.js");
const index = require("../../locales/index.js");
const giftConfig = require("../../constants/giftConfig.js");
const _hoisted_1 = {
  key: 0,
  class: "tui-gift-list"
};
const _hoisted_2 = { class: "gift-title" };
const _hoisted_3 = { class: "title" };
const _hoisted_4 = { class: "gift-item-area" };
const _hoisted_5 = ["onClick"];
const _hoisted_6 = { class: "img-wrapper" };
const _hoisted_7 = ["src", "alt"];
const _hoisted_8 = ["onClick"];
const _hoisted_9 = { class: "gift-price" };
const _sfc_main = /* @__PURE__ */ Vue.defineComponent({
  __name: "GiftList",
  setup(__props) {
    const giftList = Vue.ref([]);
    const selectedGift = Vue.ref({});
    const { getGiftList, handleSendGift, getGiftName } = useGiftList.useGiftList();
    const { localUser, rechargeMoney, isAudience } = room.useRoomStore();
    const { t } = index.useI18n();
    const handleSelectGift = (gift) => {
      selectedGift.value = gift;
    };
    const handleSendSelectedGift = async (gift) => {
      if (selectedGift.value !== gift) return;
      try {
        await handleSendGift(gift);
        selectedGift.value = {};
      } catch (error) {
        Message.default({
          type: "error",
          message: t("Insufficient balance, please recharge")
        });
        selectedGift.value = {};
      }
    };
    const handleRechargeMoney = () => {
      const result = rechargeMoney(localUser.userId, giftConfig.SingleRechargeAmount);
      if (result) {
        Message.default({
          type: "success",
          message: t("Recharge successful")
        });
      } else {
        Message.default({
          type: "error",
          message: t("Recharge failed")
        });
      }
    };
    Vue.onMounted(async () => {
      giftList.value = await getGiftList();
    });
    Vue.onUnmounted(() => {
      selectedGift.value = {};
    });
    return (_ctx, _cache) => {
      return Vue.unref(isAudience) ? (Vue.openBlock(), Vue.createElementBlock("div", _hoisted_1, [
        Vue.createElementVNode("div", _hoisted_2, [
          Vue.createElementVNode("span", _hoisted_3, Vue.toDisplayString(Vue.unref(t)("Gift")), 1),
          Vue.createElementVNode("span", {
            class: "recharge-button",
            onClick: handleRechargeMoney
          }, [
            Vue.createVNode(SvgIcon.default, {
              class: "recharge-icon",
              icon: WalletIcon.default
            }),
            Vue.createElementVNode("span", null, Vue.toDisplayString(`${Vue.unref(t)("Recharge")}(${Vue.unref(localUser).money})`), 1)
          ])
        ]),
        Vue.createElementVNode("div", _hoisted_4, [
          (Vue.openBlock(true), Vue.createElementBlock(Vue.Fragment, null, Vue.renderList(giftList.value, (item, index2) => {
            return Vue.openBlock(), Vue.createElementBlock("div", {
              class: Vue.normalizeClass(["gift-item", { active: selectedGift.value === item }]),
              onClick: ($event) => handleSelectGift(item),
              key: index2
            }, [
              Vue.createElementVNode("div", _hoisted_6, [
                Vue.createElementVNode("img", {
                  src: item.imageUrl,
                  alt: item.giftName
                }, null, 8, _hoisted_7)
              ]),
              Vue.createElementVNode("span", {
                class: "gift-name",
                onClick: ($event) => handleSendSelectedGift(item)
              }, Vue.toDisplayString(selectedGift.value === item ? Vue.unref(t)("Send") : Vue.unref(getGiftName)(item)), 9, _hoisted_8),
              Vue.createElementVNode("span", _hoisted_9, Vue.toDisplayString(item.price), 1)
            ], 10, _hoisted_5);
          }), 128))
        ])
      ])) : Vue.createCommentVNode("", true);
    };
  }
});
exports.default = _sfc_main;
