"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const Vue = require("vue");
const SVGA = require("svgaplayerweb");
const util = require("../Chat/util.js");
const giftConfig = require("../../constants/giftConfig.js");
const safelyParseGiftMsgForPlayerCard = (giftMsg) => {
  const giftMsgJson = util.safelyParse(giftMsg);
  const giftData = giftMsgJson.data.gift;
  const senderData = giftMsgJson.data.sender;
  return {
    avatarUrl: senderData.avatarUrl,
    senderName: senderData.userName,
    giftName: giftData.giftName,
    giftName_en: giftData.giftName_en || giftData.giftName,
    giftUrl: giftData.imageUrl,
    animationUrl: giftData.animationUrl,
    giftId: giftData.giftId,
    userId: senderData.userId,
    id: Date.now() + Math.random()
  };
};
const GiftCardKey = Symbol();
function createGiftCardManager() {
  const state = Vue.reactive({
    isShowing: false,
    playList: []
  });
  const manager = {
    isShowing: Vue.computed(() => state.isShowing),
    playList: Vue.computed(() => state.playList),
    async show(data) {
      state.playList.push(data);
      if (data.animationUrl) {
        playSvgAnimation(data.animationUrl, "svg-special-effects");
      }
    },
    hide() {
      state.playList.shift();
    }
  };
  Vue.provide(GiftCardKey, manager);
  return manager;
}
const animationPlayList = [];
let isPlaying = false;
let player;
let parser;
const svgaCache = /* @__PURE__ */ new Map();
function playSvgAnimation(url, canvasId) {
  if (!url || false) return;
  if (!player || !parser) {
    player = new SVGA.Player(`#${canvasId}`);
    parser = new SVGA.Parser();
  }
  player.loops = 1;
  player.onFinished(() => {
    isPlaying = false;
    if (animationPlayList.length > 0) {
      const nextUrl = animationPlayList.shift();
      startPlay(nextUrl);
    }
  });
  startPlay(url);
  async function startPlay(url2) {
    if (isPlaying) {
      animationPlayList.push(url2);
      return;
    }
    try {
      const parseUrl = url2.replace(giftConfig.animationUrlReplaceTarget, giftConfig.animationUrlReplaceContent);
      let videoItem = svgaCache.get(parseUrl);
      if (!videoItem) {
        videoItem = await new Promise((resolve, reject) => {
          parser.load(
            parseUrl,
            (item) => {
              svgaCache.set(parseUrl, item);
              resolve(item);
            },
            reject
          );
        });
      }
      if (!videoItem) throw Error("Failed to load SVGA animation:");
      player.setVideoItem(videoItem);
      player.startAnimation();
      isPlaying = true;
    } catch (error) {
      console.error(error);
    }
  }
}
function useGiftCardManager() {
  const manager = Vue.inject(GiftCardKey);
  if (!manager) {
    throw new Error("useGiftCardManager must be used within a setup()");
  }
  return manager;
}
exports.createGiftCardManager = createGiftCardManager;
exports.safelyParseGiftMsgForPlayerCard = safelyParseGiftMsgForPlayerCard;
exports.useGiftCardManager = useGiftCardManager;
