"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const Vue = require("vue");
const pinia = require("pinia");
const TUIRoomEngine = require("@tencentcloud/tuiroom-engine-js");
const room = require("../../../stores/room.js");
const basic = require("../../../stores/basic.js");
const render = require("../../../constants/render.js");
const StreamRegionPC = require("../StreamRegion/StreamRegionPC.vue.js");
const index$1 = require("../../../utils/common/logger/index.js");
const Avatar = require("../../common/Avatar.vue2.js");
const index = require("../AutoPlayFailPrompt/index.vue.js");
const useRoomEngine = require("../../../hooks/useRoomEngine.js");
const useAutoPlayFailPrompt = require("../AutoPlayFailPrompt/useAutoPlayFailPrompt.js");
const _hoisted_1 = {
  id: "streamContainer",
  class: "tui-stream-container"
};
const _hoisted_2 = {
  key: 1,
  class: "avatar-region"
};
const logPrefix = "[StreamContainer]";
const _sfc_main = /* @__PURE__ */ Vue.defineComponent({
  __name: "StreamContainer",
  setup(__props) {
    const roomEngine = useRoomEngine.default();
    const { isShowAutoPlayFailPrompt, autoPlayFailPromptText, closeAutoPlayFailPrompt } = useAutoPlayFailPrompt.default();
    const roomStore = room.useRoomStore();
    const { streamList } = pinia.storeToRefs(roomStore);
    const basicStore = basic.useBasicStore();
    const { layout } = pinia.storeToRefs(basicStore);
    const enlargeStream = Vue.ref(streamList.value[0]);
    Vue.watch(
      () => streamList.value.length,
      (val) => {
        if (val === 1) {
          enlargeStream.value = streamList.value[0];
          return;
        }
      }
    );
    const onUserVideoStateChanged = (eventInfo) => {
      var _a;
      const { userId, streamType, hasVideo } = eventInfo;
      if (streamType === TUIRoomEngine.TUIVideoStreamType.kScreenStream) {
        if (hasVideo) {
          enlargeStream.value = userId === basicStore.userId ? roomStore.localScreenStream : roomStore.streamInfoObj[`${userId}_${streamType}`];
          if (enlargeStream.value && [render.LAYOUT.RIGHT_SIDE_LIST, render.LAYOUT.TOP_SIDE_LIST].indexOf(layout.value) === -1) {
            basicStore.setLayout(render.LAYOUT.RIGHT_SIDE_LIST);
          }
          if (userId !== basicStore.userId) {
            roomStore.setHasOtherScreenShare(true);
          }
        } else {
          if (userId === ((_a = enlargeStream.value) == null ? void 0 : _a.userId)) {
            handleLargeStreamLeave();
          }
          if (userId !== basicStore.userId) {
            roomStore.setHasOtherScreenShare(false);
          }
          index$1.default.debug(
            `${logPrefix} onUserVideoStateChanged: stop`,
            userId,
            streamType
          );
        }
      }
    };
    const onSeatListChanged = (eventInfo) => {
      var _a;
      const { leftList } = eventInfo;
      const leftUserIdList = leftList.map((item) => item.userId);
      if (enlargeStream.value && leftUserIdList.includes((_a = enlargeStream.value) == null ? void 0 : _a.userId)) {
        handleLargeStreamLeave();
      }
    };
    const onRemoteUserLeaveRoom = (eventInfo) => {
      var _a;
      const {
        userInfo: { userId }
      } = eventInfo;
      if (userId === ((_a = enlargeStream.value) == null ? void 0 : _a.userId)) {
        handleLargeStreamLeave();
      }
    };
    const handleLargeStreamLeave = () => {
      if (roomStore.remoteStreamList.length === 0) {
        basicStore.setLayout(render.LAYOUT.NINE_EQUAL_POINTS);
        enlargeStream.value = null;
      } else {
        [enlargeStream.value] = roomStore.remoteStreamList;
      }
    };
    TUIRoomEngine.once("ready", () => {
      var _a, _b, _c;
      (_a = roomEngine.instance) == null ? void 0 : _a.on(
        TUIRoomEngine.TUIRoomEvents.onRemoteUserLeaveRoom,
        onRemoteUserLeaveRoom
      );
      (_b = roomEngine.instance) == null ? void 0 : _b.on(TUIRoomEngine.TUIRoomEvents.onSeatListChanged, onSeatListChanged);
      (_c = roomEngine.instance) == null ? void 0 : _c.on(
        TUIRoomEngine.TUIRoomEvents.onUserVideoStateChanged,
        onUserVideoStateChanged
      );
    });
    Vue.onUnmounted(() => {
      var _a, _b, _c;
      (_a = roomEngine.instance) == null ? void 0 : _a.off(
        TUIRoomEngine.TUIRoomEvents.onRemoteUserLeaveRoom,
        onRemoteUserLeaveRoom
      );
      (_b = roomEngine.instance) == null ? void 0 : _b.off(TUIRoomEngine.TUIRoomEvents.onSeatListChanged, onSeatListChanged);
      (_c = roomEngine.instance) == null ? void 0 : _c.off(
        TUIRoomEngine.TUIRoomEvents.onUserVideoStateChanged,
        onUserVideoStateChanged
      );
    });
    return (_ctx, _cache) => {
      return Vue.openBlock(), Vue.createElementBlock("div", _hoisted_1, [
        enlargeStream.value ? (Vue.openBlock(), Vue.createBlock(Vue.unref(StreamRegionPC.default), {
          key: 0,
          streamInfo: enlargeStream.value,
          isEnlarge: true,
          observerViewInVisible: true,
          isNeedPlayStream: true
        }, null, 8, ["streamInfo"])) : (Vue.openBlock(), Vue.createElementBlock("div", _hoisted_2, [
          Vue.createVNode(Avatar.default, { class: "avatar" })
        ])),
        Vue.unref(isShowAutoPlayFailPrompt) ? (Vue.openBlock(), Vue.createBlock(index.default, {
          key: 2,
          text: Vue.unref(autoPlayFailPromptText),
          onClose: Vue.unref(closeAutoPlayFailPrompt)
        }, null, 8, ["text", "onClose"])) : Vue.createCommentVNode("", true)
      ]);
    };
  }
});
exports.default = _sfc_main;
