"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const Vue = require("vue");
const index = require("../../../locales/index.js");
const basic = require("../../../stores/basic.js");
const room = require("../../../stores/room.js");
const pinia = require("pinia");
const Message = require("../../common/base/Message/Message.js");
const environment = require("../../../utils/environment.js");
const adapter = require("../../../utils/adapter.js");
const useRoomInviteHooks = require("../../RoomInvite/useRoomInviteHooks.js");
const roomService = require("../../../services/roomService.js");
require("@tencentcloud/tuiroom-engine-js");
require("mitt");
require("../../../services/manager/roomActionManager.js");
function useRoomInfo() {
  const { inviteLink } = useRoomInviteHooks.default();
  const basicStore = basic.useBasicStore();
  const roomStore = room.useRoomStore();
  const { roomId, isRoomLinkVisible } = pinia.storeToRefs(basicStore);
  const { masterUserId, roomName, password } = pinia.storeToRefs(roomStore);
  const { t } = index.useI18n();
  const isShowRoomInfo = Vue.ref(false);
  const arrowDirection = Vue.ref(false);
  const roomLinkConfig = roomService.roomService.getComponentConfig("RoomLink");
  const masterUserName = Vue.computed(
    () => roomStore.getUserName(masterUserId.value) || masterUserId.value
  );
  const isShowRoomInfoTitle = Vue.computed(() => masterUserName.value);
  const liveTitle = Vue.computed(() => `${roomName.value} ${t("'s living")}`);
  const roomInfoTabList = Vue.computed(() => [
    {
      id: 1,
      title: "Anchor",
      content: masterUserName.value,
      copyLink: "",
      isShowCopyIcon: false,
      visible: true
    },
    {
      id: 2,
      title: "Room ID",
      content: roomId.value,
      copyLink: roomId.value,
      isShowCopyIcon: true,
      visible: true
    },
    {
      id: 3,
      title: "Room Password",
      content: password.value,
      copyLink: password.value,
      isShowCopyIcon: true,
      visible: password.value
    },
    {
      id: 4,
      title: "Room Link",
      content: inviteLink.value,
      copyLink: inviteLink.value,
      isShowCopyIcon: true,
      visible: isRoomLinkVisible.value && roomLinkConfig.visible
    }
  ]);
  function toggleShowRoomInfoStatus() {
    isShowRoomInfo.value = !isShowRoomInfo.value;
    arrowDirection.value = !arrowDirection.value;
  }
  function handleClickOutsideRoomInfoContainer() {
    if (isShowRoomInfo.value || arrowDirection.value) {
      isShowRoomInfo.value = false;
      arrowDirection.value = false;
    }
  }
  function handleCloseRoomInfo() {
    isShowRoomInfo.value = false;
    arrowDirection.value = false;
  }
  async function onCopy(value) {
    try {
      await adapter.clipBoard(value);
      Message.default({
        message: t("Copied live link successfully"),
        type: "success"
      });
    } catch (error) {
      Message.default({
        message: t("Copied live link failure"),
        type: "error"
      });
    }
  }
  return {
    t,
    arrowDirection,
    isWeChat: environment.isWeChat,
    isShowRoomInfo,
    isShowRoomInfoTitle,
    liveTitle,
    roomInfoTabList,
    handleCloseRoomInfo,
    toggleShowRoomInfoStatus,
    handleClickOutsideRoomInfoContainer,
    onCopy
  };
}
exports.default = useRoomInfo;
