"use strict";
Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: "Module" } });
const Vue = require("vue");
const uikitBaseComponentVue3 = require("@tencentcloud/uikit-base-component-vue3");
const SvgIcon = require("../../common/base/SvgIcon.vue.js");
const LoadingIcon = require("../../common/icons/LoadingIcon.vue.js");
const useRoomControlHooks = require("./useRoomControlHooks.js");
const CreateRoomIcon = require("../../common/icons/CreateRoomIcon.vue.js");
const EnterRoomIcon = require("../../common/icons/EnterRoomIcon.vue.js");
const useRoomEngine = require("../../../hooks/useRoomEngine.js");
const basic = require("../../../stores/basic.js");
const room = require("../../../stores/room.js");
const AudioMediaControl = require("../../common/AudioMediaControl.vue.js");
const VideoMediaControl = require("../../common/VideoMediaControl.vue.js");
const TUIRoomEngine = require("@tencentcloud/tuiroom-engine-js");
const mediaAbility = require("../../../utils/mediaAbility.js");
const useDeviceManager = require("../../../hooks/useDeviceManager.js");
const _hoisted_1 = { class: "room-control-container" };
const _hoisted_2 = { class: "room-control-main" };
const _hoisted_3 = { class: "control-container" };
const _hoisted_4 = { class: "stream-preview-container" };
const _hoisted_5 = { class: "attention-info" };
const _hoisted_6 = {
  key: 0,
  class: "off-camera-info"
};
const _hoisted_7 = { class: "control-region" };
const _hoisted_8 = { class: "media-control-region" };
const _hoisted_9 = { class: "room-control-region" };
const _hoisted_10 = { class: "create-room-region" };
const _hoisted_11 = { class: "button-text" };
const _hoisted_12 = { class: "enter-room-region" };
const _hoisted_13 = { class: "button-text" };
const _hoisted_14 = {
  key: 1,
  class: "enter-room-action"
};
const _hoisted_15 = ["placeholder"];
const _sfc_main = /* @__PURE__ */ Vue.defineComponent({
  __name: "RoomControlPC",
  props: {
    userName: { default: "" },
    showLogo: { type: Boolean, default: true },
    givenRoomId: {},
    enableScheduledConference: { type: Boolean, default: true }
  },
  emits: ["create-room", "enter-room"],
  setup(__props, { expose: __expose, emit: __emit }) {
    const roomStore = room.useRoomStore();
    const basicStore = basic.useBasicStore();
    const { t } = useRoomControlHooks.default();
    const { deviceManager, initMediaDeviceList } = useDeviceManager.default({
      listenForDeviceChange: true
    });
    const props = __props;
    __expose({
      getRoomParam,
      startStreamPreview
    });
    const roomEngine = useRoomEngine.default();
    const isCameraLoading = Vue.ref(false);
    const audioVolume = Vue.ref(0);
    const isMicMuted = Vue.ref(false);
    const isCameraMuted = Vue.ref(false);
    const showEnterRoomAction = Vue.ref(Boolean(props.givenRoomId));
    const tuiRoomParam = {
      isOpenCamera: true,
      isOpenMicrophone: true,
      defaultCameraId: "",
      defaultMicrophoneId: "",
      defaultSpeakerId: ""
    };
    async function openCamera() {
      var _a, _b;
      const trtcCloud = (_a = roomEngine.instance) == null ? void 0 : _a.getTRTCCloud();
      await (trtcCloud == null ? void 0 : trtcCloud.setLocalRenderParams({
        mirrorType: basicStore.isLocalStreamMirror ? TUIRoomEngine.TRTCVideoMirrorType.TRTCVideoMirrorType_Enable : TUIRoomEngine.TRTCVideoMirrorType.TRTCVideoMirrorType_Disable,
        rotation: TUIRoomEngine.TRTCVideoRotation.TRTCVideoRotation0,
        fillMode: TUIRoomEngine.TRTCVideoFillMode.TRTCVideoFillMode_Fill
      }));
      await ((_b = roomEngine.instance) == null ? void 0 : _b.startCameraDeviceTest({
        view: "stream-preview"
      }));
    }
    async function closeCamera() {
      var _a;
      await ((_a = roomEngine.instance) == null ? void 0 : _a.stopCameraDeviceTest());
    }
    async function openAudio() {
      var _a;
      await ((_a = roomEngine.instance) == null ? void 0 : _a.startMicDeviceTest({ interval: 200 }));
    }
    async function closeAudio() {
      var _a;
      await ((_a = roomEngine.instance) == null ? void 0 : _a.stopMicDeviceTest());
    }
    async function toggleMuteAudio() {
      isMicMuted.value = !isMicMuted.value;
      tuiRoomParam.isOpenMicrophone = !isMicMuted.value;
      if (isMicMuted.value) {
        await closeAudio();
        audioVolume.value = 0;
      } else {
        await openAudio();
      }
    }
    async function toggleMuteVideo() {
      isCameraMuted.value = !isCameraMuted.value;
      tuiRoomParam.isOpenCamera = !isCameraMuted.value;
      if (isCameraMuted.value) {
        await closeCamera();
        isCameraLoading.value = false;
      } else {
        isCameraLoading.value = true;
        await openCamera();
        isCameraLoading.value = false;
      }
    }
    function getRoomParam() {
      tuiRoomParam.defaultCameraId = roomStore.currentCameraId;
      tuiRoomParam.defaultMicrophoneId = roomStore.currentMicrophoneId;
      tuiRoomParam.defaultSpeakerId = roomStore.currentSpeakerId;
      return tuiRoomParam;
    }
    const onUserVoiceVolume = (options) => {
      audioVolume.value = options.volume;
    };
    async function startStreamPreview() {
      if (!mediaAbility.isEnumerateDevicesSupported) {
        return;
      }
      isCameraLoading.value = true;
      await initMediaDeviceList();
      if (!mediaAbility.isGetUserMediaSupported) {
        isCameraLoading.value = false;
        return;
      }
      if (roomStore.microphoneList && roomStore.microphoneList.length > 0) {
        openAudio();
      }
      if (roomStore.cameraList && roomStore.cameraList.length > 0) {
        await openCamera();
      }
      isCameraLoading.value = false;
    }
    const roomId = Vue.ref(props.givenRoomId);
    Vue.watch(
      () => props.givenRoomId,
      (val) => {
        roomId.value = val;
        showEnterRoomAction.value = Boolean(val);
      },
      { immediate: true }
    );
    const emit = __emit;
    function handleCreateRoom() {
      createRoom("SpeakAfterTakingSeat");
    }
    function handleEnterRoom() {
      showEnterRoomAction.value = true;
    }
    function createRoom(mode) {
      const roomParam = getRoomParam();
      emit("create-room", {
        roomMode: mode,
        roomParam
      });
    }
    function enterRoom() {
      if (!roomId.value) {
        return;
      }
      const roomParam = getRoomParam();
      emit("enter-room", {
        roomId: String(roomId.value),
        roomParam
      });
    }
    TUIRoomEngine.once("ready", () => {
      var _a;
      startStreamPreview();
      (_a = deviceManager.instance) == null ? void 0 : _a.on(
        TUIRoomEngine.TUIRoomDeviceMangerEvents.onTestMicVolume,
        onUserVoiceVolume
      );
    });
    Vue.onBeforeUnmount(async () => {
      var _a;
      await closeAudio();
      await closeCamera();
      (_a = deviceManager.instance) == null ? void 0 : _a.off(
        TUIRoomEngine.TUIRoomDeviceMangerEvents.onTestMicVolume,
        onUserVoiceVolume
      );
    });
    return (_ctx, _cache) => {
      return Vue.openBlock(), Vue.createElementBlock("div", _hoisted_1, [
        Vue.createElementVNode("div", _hoisted_2, [
          Vue.createElementVNode("div", _hoisted_3, [
            Vue.createElementVNode("div", _hoisted_4, [
              _cache[1] || (_cache[1] = Vue.createElementVNode("div", {
                id: "stream-preview",
                class: "stream-preview"
              }, null, -1)),
              Vue.createElementVNode("div", _hoisted_5, [
                isCameraMuted.value ? (Vue.openBlock(), Vue.createElementBlock("span", _hoisted_6, Vue.toDisplayString(Vue.unref(t)("Off Camera")), 1)) : Vue.createCommentVNode("", true),
                isCameraLoading.value ? (Vue.openBlock(), Vue.createBlock(SvgIcon.default, {
                  key: 1,
                  icon: LoadingIcon.default,
                  class: "loading"
                })) : Vue.createCommentVNode("", true)
              ])
            ]),
            Vue.createElementVNode("div", _hoisted_7, [
              Vue.createElementVNode("div", _hoisted_8, [
                Vue.createVNode(AudioMediaControl.default, {
                  class: "media-control-item",
                  "has-more": true,
                  "is-muted": isMicMuted.value,
                  "audio-volume": audioVolume.value,
                  onClick: toggleMuteAudio
                }, null, 8, ["is-muted", "audio-volume"]),
                Vue.createVNode(VideoMediaControl.default, {
                  class: "media-control-item",
                  "has-more": true,
                  "is-muted": isCameraMuted.value,
                  onClick: toggleMuteVideo
                }, null, 8, ["is-muted"])
              ]),
              Vue.createElementVNode("div", _hoisted_9, [
                Vue.createElementVNode("div", _hoisted_10, [
                  Vue.createVNode(Vue.unref(uikitBaseComponentVue3.TUIButton), {
                    size: "large",
                    type: "primary",
                    onClick: Vue.withModifiers(handleCreateRoom, ["stop"])
                  }, {
                    default: Vue.withCtx(() => [
                      Vue.createVNode(SvgIcon.default, { icon: CreateRoomIcon.default }),
                      Vue.createElementVNode("span", _hoisted_11, Vue.toDisplayString(Vue.unref(t)("New Live Room")), 1)
                    ]),
                    _: 1
                  })
                ]),
                Vue.createElementVNode("div", _hoisted_12, [
                  !showEnterRoomAction.value ? (Vue.openBlock(), Vue.createBlock(Vue.unref(uikitBaseComponentVue3.TUIButton), {
                    key: 0,
                    size: "large",
                    type: "primary",
                    onClick: handleEnterRoom
                  }, {
                    default: Vue.withCtx(() => [
                      Vue.createVNode(SvgIcon.default, { icon: EnterRoomIcon.default }),
                      Vue.createElementVNode("span", _hoisted_13, Vue.toDisplayString(Vue.unref(t)("Join Live Room")), 1)
                    ]),
                    _: 1
                  })) : Vue.createCommentVNode("", true),
                  showEnterRoomAction.value ? (Vue.openBlock(), Vue.createElementBlock("div", _hoisted_14, [
                    Vue.withDirectives(Vue.createElementVNode("input", {
                      "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => roomId.value = $event),
                      class: "input",
                      placeholder: Vue.unref(t)("Enter room ID"),
                      onKeyup: Vue.withKeys(enterRoom, ["enter"])
                    }, null, 40, _hoisted_15), [
                      [Vue.vModelText, roomId.value]
                    ]),
                    Vue.createElementVNode("div", {
                      class: Vue.normalizeClass([
                        "enter-button",
                        { active: roomId.value && roomId.value.length > 0 }
                      ]),
                      onClick: enterRoom
                    }, [
                      Vue.createVNode(SvgIcon.default, { icon: EnterRoomIcon.default })
                    ], 2)
                  ])) : Vue.createCommentVNode("", true)
                ])
              ])
            ])
          ])
        ])
      ]);
    };
  }
});
exports.default = _sfc_main;
